const crypto = require('crypto');
const {log, constants} = require('utils-nxg-cg');
const {convertToUtf8} = require('utils-nxg-cg/utils/helpers');
const {flags} = require('utils-nxg-cg/utils/constants');
const {md5sum} = constants;

/**
 * Method to check sum md5 in content
 * @param msg
 * @param cfg
 * @returns {boolean}
 */
function checkSumMD5(msg = {}, cfg = {}) {
    const {data} = msg;
    let content;
    let _md5sum;
    if (!data) return false;
    if (!data.hasOwnProperty(md5sum)) {
        if (!cfg.hasOwnProperty(md5sum)) {
            return true;
        } else {
            _md5sum = cfg[md5sum];
        }
    } else {
        _md5sum = data[md5sum];
    }
    if (!_md5sum) return false;
    if (!data.content) {
        if (!cfg.content) {
            return false;
        } else {
            content = cfg.content;
        }
    } else {
        content = data.content;
    }
    log.debug('validando:', _md5sum === getMd5ID(convertToUtf8(content)))
    return _md5sum === getMd5ID(convertToUtf8(content));
}

/**
 * Method to create sum from components
 * @param data
 * @param flag property only for sftp, ftp, ftps components, only use if flag is GETFILE
 * @returns {string}
 */
function createSum(data, flag = '') {
    if (flag) {
        if (flag !== flags.GETFILE)
            return '';
    }
    log.debug('md5sum creado:', getMd5ID(convertToUtf8(data)))
    return getMd5ID(convertToUtf8(data));
}


/**
 * Method that transforms a string into an MD5 id
 * @param content
 * @returns {string}
 */
const getMd5ID = (content) => {
    try {
        return crypto.createHash('md5').update(content).digest("hex");
    } catch (error) {
        log.error(`Error Creating MD5 id: ${error}`);
        throw Error(error);
    }
}

module.exports = {
    checkSumMD5,
    createSum,
    getMd5ID
};